@@ -173,6 +173,20 @@ class FileRecord:
         ext = ext[0:3]
         self._ext = ext
     
+    @property
+    def fullname(self):
+        """
+        Helper property, returns name for directories and name.ext for files.
+        Read only.
+        """
+        if self.attributes["directory"]:
+            return self.name
+        return self.name + b"." + self.ext
+    
+    @fullname.setter
+    def fullname(self, value):
+        pass
+    
     @property
     def size(self):
         """
@@ -422,12 +436,19 @@ class Directory:
     a directory/folder in a FAT32 filesystem. As with FileHande, this class is
     strange, because it's more involved than you'd usually find, and has to
     take care of some things which are usually responsibility of the OS.
+
+    :param filesystem: the base filesystem (of class FAT32) to which the
+        Directory belongs
+    :param record: the FileRecord (Directory Entry) for the directory
+    :param parent: (Directory) parent of the (new) directory, used to build a
+        path string
+    :return: Directory object in `filesystem `for the given `record`
     """
-    def __init__(self, filesystem, record, *, parent=None, cluster=2):
+    def __init__(self, filesystem, record, *, parent=None):
         self._filesystem = filesystem
         if record is None:
             record = FileRecord(bytes(32))
-            record.cluster = cluster
+            record.cluster = filesystem.root_cluster
         self._record = record
         self.cluster = record.cluster
         # a bit of a hack for the root cluster
@@ -508,7 +529,7 @@ class FileHandle:
     object, because it actually deals with the filesystem on a level closer to
     the OS.
     """
-    def __init__(self, filesystem, record, mode, *, parent=None):
+    def __init__(self, filesystem, record, mode="rb", *, parent=None):
         self._filesystem = filesystem
         self._record     = record
         self._mode       = mode
@@ -614,7 +635,7 @@ class FileHandle:
             self._ccluster = ncluster
             c_idx -= 1
             ncluster = self._filesystem.fat1[self._ccluster]
-        if c_idx >= 0 and (ncluster >= 0x0ffffff0):  # we got to the last cluster
+        if offset >= record.size:  # we went over the end of the file
             self._buffer     = bytearray(filesystem._read_cluster(self._ccluster))
             self._file_pos   = record.size
             self._buffer_pos = record.size % bsize
@@ -740,8 +761,44 @@ class FAT32:
         assumes the basic functionality of the filesystem is already working
         and adds ease-of-use things.
         """
-        root = Directory(self, None, cluster=self.root_cluster)
+        root = Directory(self, None)
         v_id = root.files[0]
         if v_id.attributes["volume-id"]:
             root.path = (v_id.name + v_id.ext).decode("ascii)")
         self.root = root
+    
+    def open(self, path):
+        """
+        Opens a file or directory found in the absolute path passed.
+
+        :param path: absolute path to open.
+        :returns: FileHandle or Directory object, depending on the path.
+        """
+        path  = path.upper()
+        path  = path.encode("latin-1")  # TODO: make the encoding an attribute...
+        path  = path.replace(b"\\", b"/")
+        parts = path.split(b"/")[1:]
+        # we ignore the first one, assuming it's the root -- remember, these
+        # should be absolute paths!
+        obj = self.root
+        for part in parts:
+            try:
+                files = obj.files
+            except AttributeError:
+                raise FileNotFoundError(f"{obj.path} is not a Directory!")
+            try:
+                idx = next( idx
+                            for idx, f in enumerate(files)
+                            if f.fullname == part
+                )
+            except StopIteration:
+                raise FileNotFoundError(f"No such file or directory {obj.path}\\{part}")
+            # if we're here, we got a a directory
+            record = obj.files[idx]
+            if record.attributes["directory"]:
+                obj = Directory(self, record, parent=obj)
+            else:
+                obj = FileHandle(self, record, parent=obj)
+                # hopefully this happens just once, otherwise 
+        # we could safely assume our object is just fine...
+        return obj
